#!/usr/bin/python
# -*- coding: UTF-8 -*-

import urllib



def isData(lines):
	if len(lines) > 6:
		if '¿ù' in lines[-4]:
			return True
		else:
			return False
	else:	
		return False


def getData(url):
	opener = urllib.URLopener()
	datafp = opener.open(url)
	return  datafp.readlines()

def GetOne(datalist):
	#time = datalist[-4][ datalist[-4].find("title='") + 6 : ("'",1)[0]
	time = datalist[-4].split("title='",1)[1].split("'",1)[0]
	url = datalist[-6].split('a href="',1)[1].split(' ',1)[:-1][0] 
	return ( url[: url.find("&PHPSESSID")] , time )

def DataParser(data):
	Tr = False
	DataBuffer = []
	Articles = []
	for lines in data:
		if lines.startswith("<tr") and Tr is not True:
			DataBuffer = []
			Tr = True
		if Tr is True:
			DataBuffer.append(lines)
		if Tr is True and lines.startswith("</tr") and lines.strip() == "</tr>":
			if isData(DataBuffer):
				Articles.append(GetOne(DataBuffer))
			Tr = False
	return Articles



#!/usr/bin/python

import sys , os

try:
	from cfg import CFG
except:
	pass
from cPickle import dump

from urllib import quote
from ListParser import *
from ArticleParser import *
from RSSMaker import *
from HtmlStrip import strip
from RSSReader import GetLastArticleTime
from RSSWriter import CheckIt

Listdata = getData(CFG["ZBINFO"]["url"])
ArticleDataList = []
for url , time in  DataParser(Listdata):
	url = os.path.join( CFG["BASEURL"] , url ) 
	ArticleData = getData( url )
	ArticleDataList.append(ArticleParse(ArticleData) )
	ArticleDataList[-1]["TIME"] = time
	#ArticleDataList[-1]["URL"] = quote(url)
	ArticleDataList[-1]["URL"] = url
	#break
NewRss = RssMaker(ArticleDataList,CFG,strip=strip)
if os.path.exists(CFG["ZBINFO"]["xmlfile"]):
	if CheckIt(NewRss,CFG["ZBINFO"]["xmlfile"],GetLastArticleTime):
		print "NEW!"
		raise SystemExit
NewRss.seek(0)
file(CFG["ZBINFO"]["xmlfile"],'w').write(NewRss.read())



#!/usr/bin/python


def GetLastArticleTime(filefp):
	Checker = 0
	filefp.seek(0)
	for line in filefp:
		if '<pubDate>' in line:
			if Checker == 1:
				break
			Checker += 1
	line = line.replace('<pubDate>','')
	line = line.replace('</pubDate>','')
	line = line.strip()
	return line



#!/usr/bin/python

import sys , os
from urlparse import urlparse
from urlparse import urlunparse
from ConfigParser import ConfigParser
cfg = ConfigParser()

if os.path.exists("config.ini"):
	cfg.read("config.ini")
else:
	raise ConfigFileNotExist

CFG = {}

for sections in cfg.sections():
	CFG[sections] = {}
	for keys , data in cfg.items(sections):
		CFG[sections][keys] = data
tmptpl = urlparse(CFG["ZBINFO"]["url"])
BASEURL = urlunparse((tmptpl[0] , tmptpl[1] , os.path.dirname(tmptpl[2]),'','',''))
CFG["BASEURL"] = BASEURL



#!/usr/bin/python
# from source http://aspn.activestate.com/ASPN/Cookbook/Python/Recipe/52281/index_txt
# http://aspn.activestate.com/ASPN/Cookbook/Python/Recipe/52281

import sgmllib, string

class StrippingParser(sgmllib.SGMLParser):

	# These are the HTML tags that we will leave intact
	valid_tags = ('b', 'a', 'i', 'br', 'p','img')
	#valid_tags = ('br')

	from htmlentitydefs import entitydefs # replace entitydefs from sgmllib
	
	def __init__(self):
		sgmllib.SGMLParser.__init__(self)
		self.result = ""
		self.endTagList = [] 
		
	def handle_data(self, data):
		if data:
			self.result = self.result + data

	def handle_charref(self, name):
		self.result = "%s&#%s;" % (self.result, name)
		
	def handle_entityref(self, name):
		if self.entitydefs.has_key(name): 
			x = ';'
		else:
			# this breaks unstandard entities that end with ';'
			x = ''
		self.result = "%s&%s%s" % (self.result, name, x)
	
	def unknown_starttag(self, tag, attrs):
		""" Delete all tags except for legal ones """
		if tag in self.valid_tags:	   
			self.result = self.result + '<' + tag
			for k, v in attrs:
				if string.lower(k[0:2]) != 'on' and string.lower(v[0:10]) != 'javascript':
					self.result = '%s %s="%s"' % (self.result, k, v)
			endTag = '</%s>' % tag
			self.endTagList.insert(0,endTag)	
			self.result = self.result + '>'
				
	def unknown_endtag(self, tag):
		if tag in self.valid_tags:
			self.result = "%s</%s>" % (self.result, tag)
			remTag = '</%s>' % tag
			try:
				self.endTagList.remove(remTag)
			except:
				pass

	def cleanup(self):
		""" Append missing closing tags """
		for j in range(len(self.endTagList)):
				self.result = self.result + self.endTagList[j]	
		

def strip(s):
	""" Strip illegal HTML tags from string s """
	parser = StrippingParser()
	parser.feed(s)
	parser.close()
	parser.cleanup()
	return parser.result




#!/usr/bin/python
# -*- coding: UTF-8 -*-


def ArticleParse(data):
	lc = 0
	Topic = False
	Author = False
	Homepage = False
	Contents = False
	ContentsEnd = False

	for lines in data:
		if Author is False:
			if 'ÀÌ ¸§ &nbsp;&nbsp;' in lines:
				AuthorLine = lc + 1
				Author = True
		elif Homepage is False:
			if 'Homepage &nbsp;&nbsp;' in lines:
				HomepageLine = lc + 1
				Homepage = True
		elif Topic is False:
			if 'Á¦ ¸ñ &nbsp;&nbsp;' in lines:
				TopicLine = lc + 1
				Topic = True
		elif Contents is False:
			if lines.startswith('     <span style=line-height:160%>'):
				ContentsS = lc + 1
				Contents = True
		elif ContentsEnd is False:
			if lines.startswith('     </span>'):
				ContentsE = lc - 1
				ContentsEnd = True
				break
		else:
			pass
		lc +=1
	CON = {}
	#print "AutorLine :" + data[AuthorLine][ data[AuthorLine].find('>') + 1 : -6 ]
	CON["AUTHOR"] = data[AuthorLine][ data[AuthorLine].find('>') + 1 : -6 ]
	try:
		#print "HomePageInfo :" + data[HomepageLine].split("'",2)[1]
		CON["HOMEPAGE"] = data[HomepageLine].split("'",2)[1]
	except:
		CON["HOMEPAGE"] = None
	#print "TopicInfo:" + data[TopicLine][ data[TopicLine].find('>') + 1 : -6 ]
	CON["TOPIC"] =  data[TopicLine][ data[TopicLine].find('>') + 1 : -6 ]
	#print "con:" + repr(data[ContentsS:ContentsE])
	CON["CONTENTS"] = data[ContentsS:ContentsE]
	return CON
